API Changes for 3.10.7
======================

Development
-----------

New minimum version of pyparsing
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

The minimum required version of ``pyparsing`` has been updated from 2.3.1 to 3.0.0.
